/*
 *========================================================================== 
 * Copyright 1996 Avinash Chopde, All Rights Reserved.
 */

static char S_RCSID[] = "$Header: /home/cvsroot/itrans/nextrel/src/itohtml.c,v 1.1 1997/05/17 19:10:52 avinash Exp $";

#include "itrans.h"

typedef enum {USE_7_BITS_ONLY=1,USE_8_BITS} html_output_mode;

static html_output_mode S_current_mode = USE_7_BITS_ONLY;

/* =================================================================== */
/* just creates a array of "pcodes" -- all dx, dy is ignored
 * this is used to generate romanized sanskrit output (CS/CSX) from
 * ITRANS input text, so that the output text can be displayed on
 * the PC or on the Mac, using the CSUtopia or other CS/CSX TrueType fonts.
 * Output is in HTML format (raw characters output for char codes 0..127,
 * while chars 128..255 are output using &###; codes
 */
int cus_to_html(comp_unit_t* cus, /* chain of font characters to output */
	      pschar_t fm[256], /* unused */
	      char out[]) /* the characters returned here */
{
    int pcode;

    while (cus) {
	pcode = cus->u_pschar;

#ifdef DEBUG
fprintf(stderr, "tohtml: constructing char: dx %d dy %d pcode %d\n", dx, dy, pcode);
#endif /*DEBUG*/

	if (pcode != NO_PSCHAR) {
	    /* output this character -- char code will be between 0 & 255
	     */ 
	    if (pcode == '<') {
	        sprintf(out, "&lt;");
	    } else if (pcode == '>') {
	        sprintf(out, "&gt;");
	    } else if (pcode == '&') {
	        sprintf(out, "&amp;");
	    } else if (pcode == '"') {
	        sprintf(out, "&#%03d;", pcode); /* does &quot exist? */
	    } else if (isprint(pcode)) {
		out[0] = (char) pcode;
		out[1] = '\0';
	    } else { /* print out char code */
		if (S_current_mode == USE_7_BITS_ONLY) {
		    sprintf(out, "&#%03d;", pcode);
		} else {
		    out[0] = (char) pcode;
		    out[1] = '\0';
		}
	    }
	    out += strlen(out);
	}
	
	cus = cus->next;
    } /* while cus */

    *out = '\0';

    return TRUE;
}
/* =================================================================== */
int outhtml_start(int fsize)
{
    return TRUE;
}
int outhtml_end()
{
    return TRUE;
}
int outhtml_mode_ascii(int use_ascii_only)
{
    html_output_mode prev = S_current_mode;

    if (use_ascii_only) {
        S_current_mode = USE_7_BITS_ONLY;
    } else {
        S_current_mode = USE_8_BITS;
    }
    return (prev == USE_7_BITS_ONLY ? TRUE : FALSE);
}
/* ============================^ itohtml.c ^ =========================== */
